aboutsummaryrefslogtreecommitdiffstats
path: root/dbgprint.c
diff options
context:
space:
mode:
authorJaroslav Hensl <emulator@emulace.cz>2024-05-27 00:26:45 +0200
committerJaroslav Hensl <emulator@emulace.cz>2024-05-27 00:26:45 +0200
commit840a49797481567eea7f17017ae5f0a9076fee0d (patch)
tree07a05e19a937330144b330d882933f50ca14abe7 /dbgprint.c
parent60c366fe3c99d042036fb36affe3f9c73f83391f (diff)
downloadvmdisp9x-840a49797481567eea7f17017ae5f0a9076fee0d.tar.gz
screen target support + QXL inf
Diffstat (limited to 'dbgprint.c')
-rw-r--r--dbgprint.c2
1 files changed, 1 insertions, 1 deletions
diff --git a/dbgprint.c b/dbgprint.c
index f8a9640..a8286c4 100644
--- a/dbgprint.c
+++ b/dbgprint.c
@@ -64,7 +64,7 @@ static int serial_inited = 0;
static void init_serial() {
outp(INFO_PORT + 1, 0x00); // Disable all interrupts
outp(INFO_PORT + 3, 0x80); // Enable DLAB (set baud rate divisor)
- outp(INFO_PORT + 0, 0x12); // Set divisor to 3 (lo byte) 38400 baud
+ outp(INFO_PORT + 0, 0x01); // Set divisor to 3 (lo byte) 38400 baud 0x0C = 9600, 0x01 = 115200
outp(INFO_PORT + 1, 0x00); // (hi byte)
outp(INFO_PORT + 3, 0x03); // 8 bits, no parity, one stop bit
outp(INFO_PORT + 2, 0xC7); // Enable FIFO, clear them, with 14-byte threshold